@@ -281,7 +281,7 @@ if (!$finish) {
       echo '<BR><BR><H1><STRONG><CENTER>' . _("Upload Completed!") . '</STRONG></H1>' . _("Click on the link below to verify your work.") . '</CENTER>';
    }
 
-   echo '<BR><BR><CENTER><A HREF="' . SM_PATH . 'src/addressbook.php">' . _("Addresses") . '</A></CENTER>
+   echo '<BR><BR><CENTER><A HREF="../../src/addressbook.php">' . _("Addresses") . '</A></CENTER>
    ';
 }
 
