@@ -330,7 +330,8 @@ function sent_conf_message_sent_do() {
 
 // Determine if there was a message just sent, if so, display message
 //
-function sent_conf_check_is_sent_do() {
+function sent_conf_check_is_sent_do() 
+{
 
 
    // get global variable for versions of PHP < 4.1
@@ -341,6 +342,16 @@ function sent_conf_check_is_sent_do() {
    }
 
 
+   // strange, but on replies, the session doesn't seem
+   // to be getting started before output is being sent
+   // so we force it here
+   //
+//   if (stristr($_SERVER['SCRIPT_NAME'], 'compose.php'))
+//      compatibility_sqsession_is_active();
+// Nope, doesn't do the trick; seems that even though the
+// session is started, it throughs up errors... whatever!
+
+
    // this is called in the generic header, so we 
    // only want to do this when we are on the right_main
    // page (unless "compose in new window" is on, in
@@ -1132,7 +1143,8 @@ function sc_parseEmailAddresses($emailAddressWithJunk, $header='')
 
 // clear out sent indicator
 //
-function sent_conf_compose_bottom_do() {
+function sent_conf_compose_bottom_do() 
+{
 
    global $sent_conf_message_sent_status;
    $sent_conf_message_sent_status = 'not_sent';
